Functions — PolSARtools 0.10 documentation

Skip to main content
`Ctrl`+`K`

# Functions

## Full-pol functions

Full-pol functionalities require the SAR data in the form of scattering (S2), covariance (C3) or coherency matrix (T3). A typical file structures of S2, T3 and C3 matrices are provded in:

- Full-pol data format
  - S2 – Scattering Matrix
  - C3 / C4 – Covariance Matrix
  - T3 / T4 – Coherency Matrix
  - Matrix Compatibility Overview

Following are the avaialble functions for full-pol data:

- H/A/α Decomposition (`h_a_alpha_fp`)
- Touzi decomposition (`tsvm`)
- Yamaguchi 4-Component decomposition (`yamaguchi_4c`)
- Freeman 3-Component decomposition (`freeman_3c`)
- Freeman 2-Component decomposition (`freeman_2c`)
- Model Free 3-Component decomposition (`mf3cf`)
- Model Free 4-Component decomposition (`mf4cf`)
- Neumann decomposition (`neumann_parm`)
- Non-negative Eigen Value decomposition (`nned_fp`)
- Shannon entropy (`shannon_h_fp`)
- Praks polarimetric parameters (`praks_parm_fp`)
- Radar Vegetation Index (`rvi_fp` )
- Generalized volume based Radar Vegetation Index (`grvi`)
- Polarimetric Radar Vegetation Index (`prvi_fp` )
- Degree of Polarization (`dop_fp`)

## Compact-pol functions

Compact-pol functionalities require the SAR data in the form of 2x2 covariance matrix (C2). A typical file structure of C2 matrix is provded in:

- Compact-pol data format

Following are the avaialble functions for compact-pol data:

- Compact-pol Radar Vegetation Index (`cprvi`)
- improved S-\(\Omega\) decomposition (`s_omega`)
- Model Free 3-Component decomposition (`mf3cc`)
- Degree of Polarization (`dop_cp`)

## Dual-pol functions

Dual-pol functionalities require the SAR data in the form of 2x2 covariance matrix (C2) or 2x2 coherency matrix (T2) for dual-co-pol. A typical file structures of C2/T2 matrix is provded in:

- Dual-pol data format
  - C2 – Dual-pol Covariance Matrix
  - T2 – Dual-co-pol Coherency Matrix

Following are the avaialble functions for dual-pol data:

- Radar Vegetation Index (`rvi_dp`)
- Dual-pol Radar Vegetation Index (`dprvi`)
- Polarimetric Radar Vegetation Index (`prvi_dp`)
- Degree of Polarization (`dop_dp`)
- H/α decomposition (`h_alpha_dp`)
- Shannon entropy (`shannon_h_dp`)
- Model Free 3-Component decomposition for dual-co-pol (`mf3cd`)
- Dual-pol Radar Vegetation Index for GRD (`dprvic`)
- Dual polarimetric descriptors (`dp_desc`)
- Dual-pol Radar Built-up Index (`dprbi`)
- Dual-pol Radar Surface Index (`dprsi`)
- Dual-pol scattering power components (`powers_dp`)
- Dual-pol Radar Built-up Index for GRD (`dprbic`)
- Dual-pol Radar Surface Index for GRD (`dprsic`)
- Dual-pol scattering power components for GRD (`powers_dp_grd`)

## Analysis functions

- Generate Pauli RGB for FP data (`pauli_rgb`)
- Generate false color RGB for DP/CP data (`rgb_dp`)
- Generate false color RGB for decomposed powers (`rgb`)
- Generate polarimetric signatures for FP data (`signature_fp`)
- Full-pol H-alpha plot (`plot_h_alpha_fp`)
- Dual-pol H-alpha plot (`plot_h_alpha_dp`)
- Full-pol H-A-alpha plot (`plot_h_a_alpha_fp`)
- Full-pol H-alpha clusters (`cluster_h_alpha_fp`)
- Full-pol H-theta plot (`plot_h_theta_fp`)
- Compact-pol H-theta plot (`plot_h_theta_cp`)

## Polarimetric speckle filters

- Refined-Lee filter (`filter_refined_lee`)
- Boxcar filter (`filter_boxcar`)

## Preprocessing

- Clip PolSAR data (`clip`)
- Multi-looking (`mlook`)
- Convert single-look S (S2,Sxy) (`convert_S`)

## Other functions

- Derive stokes parameters (`stokes_parm`)
- Prepare DEM (`prepare_dem`)